summaryrefslogtreecommitdiff
path: root/install.php
diff options
context:
space:
mode:
authorGábor Hojtsy <gabor@hojtsy.hu>2007-05-08 22:10:22 +0000
committerGábor Hojtsy <gabor@hojtsy.hu>2007-05-08 22:10:22 +0000
commita7845659e8f383167f801975a44e8df06b26e40d (patch)
treeb8c32411620b441f8d14d8aa75ae53f9e6d0f667 /install.php
parentd7681a355f9f6afb10ba752d93d8f5aacd2b1a40 (diff)
downloadbrdo-a7845659e8f383167f801975a44e8df06b26e40d.tar.gz
brdo-a7845659e8f383167f801975a44e8df06b26e40d.tar.bz2
#99011: FILE_WRITEABLE typofix to FILE_WRITABLE, patch by myself
Diffstat (limited to 'install.php')
-rw-r--r--install.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/install.php b/install.php
index 0e6786173..fe01c1f2d 100644
--- a/install.php
+++ b/install.php
@@ -156,23 +156,23 @@ function install_change_settings($profile = 'default', $install_locale = '') {
// The existing database settings are not working, so we need write access
// to settings.php to change them.
- $writeable = FALSE;
+ $writable = FALSE;
$file = $conf_path;
// Verify the directory exists.
if (drupal_verify_install_file($conf_path, FILE_EXIST, 'dir')) {
// Check to see if a settings.php already exists
if (drupal_verify_install_file($settings_file, FILE_EXIST)) {
- // If it does, make sure it is writeable
- $writeable = drupal_verify_install_file($settings_file, FILE_READABLE|FILE_WRITEABLE);
+ // If it does, make sure it is writable
+ $writable = drupal_verify_install_file($settings_file, FILE_READABLE|FILE_WRITABLE);
$file = $settings_file;
}
else {
// If not, makes sure the directory is.
- $writeable = drupal_verify_install_file($conf_path, FILE_READABLE|FILE_WRITEABLE, 'dir');
+ $writable = drupal_verify_install_file($conf_path, FILE_READABLE|FILE_WRITABLE, 'dir');
}
}
- if (!$writeable) {
+ if (!$writable) {
drupal_set_message(st('The @drupal installer requires write permissions to %file during the installation process.', array('@drupal' => drupal_install_profile_name(), '%file' => $file)), 'error');
drupal_set_title(st('Drupal database setup'));